/**
 * Java
 * 
 * Copyright 2013 IS2T. All rights reserved.
 * For demonstration purpose only.
 * IS2T PROPRIETARY. Use is subject to license terms.
 */
package com.is2t.appnote;

import ej.bon.Immortals;

public class SensorManager implements Runnable {

	/**
	 * Number of sensors to be managed.
	 */
	private int nbSensors;
	/**
	 * Sensors values buffer.
	 */
	private int[] sensorsValues;

	/**
	 * Constructor.
	 */
	public SensorManager() {
		nbSensors = NativesInterface.getNumberOfSensors();
		sensorsValues = new int[nbSensors];
		// Before sharing buffer, we have to set it as Immortal.
		sensorsValues = (int[]) Immortals.setImmortal(sensorsValues);
	}

	/*
	 * (non-Javadoc)
	 * @see java.lang.Runnable#run()
	 */
	public void run() {
		System.out.println("--- 1st step : application reads buffer filled by a native process ---");
		NativesInterface.init(sensorsValues);
		try {
			// Wait for Mock initialization
			Thread.sleep(500);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
		// Read sensors values
		System.out.println("[Application] - Read sensors values : ");
		for (int i = 0; i < this.nbSensors; i++) {
			int sensorValue = this.sensorsValues[i];
			System.out.println("[Application] - Sensor_" + i + " = " + sensorValue);
		}
		System.out.println("--- 2nd step : native process reads buffer filled by the application ---");
		// Update sensors values
		System.out.println("[Application] - update sensor values");
		for (int i = 0; i < this.nbSensors; i++) {
			this.sensorsValues[i] = i;
		}
		try {
			// Wait for Mock execution
			Thread.sleep(500);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

}
